package cse;


import java.io.Reader;

import polyglot.ast.NodeFactory;
import polyglot.frontend.CupParser;
import polyglot.frontend.FileSource;
import polyglot.frontend.Parser;
import polyglot.frontend.Scheduler;
import polyglot.lex.Lexer;
import polyglot.types.TypeSystem;
import polyglot.util.ErrorQueue;
import cse.Hw1Scheduler;
import cse.Topics;
import cse.ast.cseExtFactory_c;
import cse.ast.cseLang_c;
import cse.ast.cseNodeFactory_c;
import cse.parse.Grm;
import cse.parse.Lexer_c;
import cse.types.cseTypeSystem_c;

/**
 * Extension information for hw1 extension.
 */
public class ExtensionInfo extends polyglot.frontend.JLExtensionInfo {
    static {
        // force Topics to load
        @SuppressWarnings("unused")
        Topics t = new Topics();
    }

    @Override
    public String defaultFileExtension() {
        return "java";
    }

    @Override
    public String compilerName() {
        return "hw1c";
    }

    @Override
    public Parser parser(Reader reader, FileSource source, ErrorQueue eq) {
        Lexer lexer = new Lexer_c(reader, source, eq);
        Grm grm = new Grm(lexer, ts, nf, eq);
        return new CupParser(grm, source, eq);
    }

    @Override
    protected NodeFactory createNodeFactory() {
        return new cseNodeFactory_c(cseLang_c.instance, new cseExtFactory_c());
    }

    @Override
    protected TypeSystem createTypeSystem() {
        return new cseTypeSystem_c();
    }
    
    @Override
    public Scheduler createScheduler() {
        return new Hw1Scheduler(this);
    }

}
